==> lire_1.5.orig.tar.gz: lire-1.5/database/po/lire-database.pot.pl <==
# REFERENCE: database.cfg
__( q{Database Report} );
# REFERENCE: schema:database
__( q{DLF Schema for Database service} );
# REFERENCE: schema:database
__( q{A record in the <type>database</type> DLF schema represents
   one event in the database. This may be a connection from a client,
   a SQL query, etc.
  } );
# REFERENCE: schema:database
__( q{Timestamp} );
# REFERENCE: schema:database
__( q{The time at which the event occured.} );
# REFERENCE: schema:database
__( q{User} );
# REFERENCE: schema:database
__( q{The name of the user who executed the command.} );
# REFERENCE: schema:database
__( q{Client Host} );
# REFERENCE: schema:database
__( q{The host from which the user executed the command.} );
# REFERENCE: schema:database
__( q{Query Action} );
# REFERENCE: schema:database
__( q{The command that was executed. Commands you are likely to
    encounter are <constant>connect</constant>,
    <constant>disconnect</constant>, <constant>shutdown</constant> and
    <constant>query</constant>. 
   } );
# REFERENCE: schema:database
__( q{database} );
# REFERENCE: schema:database
__( q{The database name on which the command was executed.} );
# REFERENCE: schema:database
__( q{query} );
# REFERENCE: schema:database
__( q{When the <structfield>command</structfield> field is a
    <constant>query</constant>, this field contains the actual SQL
    query that was executed.
   } );
# REFERENCE: schema:database
__( q{Success?} );
# REFERENCE: schema:database
__( q{Did the command succeeded?} );
# REFERENCE: schema:database
__( q{Error} );
# REFERENCE: schema:database
__( q{When the <structfield>success</structfield> field is
    <constant>false</constant>, i.e. when the command failed, this
    field should contains the logged error message.} );
# REFERENCE: schema:database
__( q{Connection ID} );
# REFERENCE: schema:database
__( q{An "appropriate" "connection label" for the backend that can
    be used for session analysis in conjunction with the
    <structfield>timestamp</structfield>,
    <structfield>username</structfield> and
    <structfield>database</structfield> fields. This can be a
    connection identifier, a PID, a real session ID or whatever makes
    sense in the particular backend.
   } );
# REFERENCE: report:database:actions-by-period
__( q{Actions By Period Database Report} );
# REFERENCE: report:database:actions-by-period
__( q{This report shows the number of actions
   in configurable time periods.
  } );
# REFERENCE: report:database:actions-by-period
__( q{This parameter controls the time period over which the
     deliveries are aggregated.
    } );
# REFERENCE: report:database:actions-by-period
__( q{Actions By $period Period} );
# REFERENCE: report:database:actions-by-period
__( q{Period} );
# REFERENCE: report:database:actions-by-period
__( q{Actions} );
# REFERENCE: report:database:actions-by-period
__( q{% Total} );
# REFERENCE: report:database:top-databases
__( q{Most Accessed Databases Database Report} );
# REFERENCE: report:database:top-databases
__( q{This report lists the databases that were the most accessed.} );
# REFERENCE: report:database:top-databases
__( q{This parameter controls the number of databases to
     display in the report.
    } );
# REFERENCE: report:database:top-databases
__( q{Most Used Databases, Top $databases_to_show} );
# REFERENCE: report:database:top-databases
__( q{Actions} );
# REFERENCE: report:database:top-databases
__( q{Actions} );
# REFERENCE: report:database:top-querytypes
__( q{Queries By Type} );
# REFERENCE: report:database:top-querytypes
__( q{This report shows the number of queries by query type.} );
# REFERENCE: report:database:top-querytypes
__( q{Queries by Type} );
# REFERENCE: report:database:top-querytypes
__( q{Queries} );
# REFERENCE: report:database:top-querytypes
__( q{% Total} );
# REFERENCE: report:database:top-users
__( q{Most Active Users Database Report} );
# REFERENCE: report:database:top-users
__( q{This report lists the users that do the most actions.} );
# REFERENCE: report:database:top-users
__( q{This parameter controls the number of users to
     display in the report.
    } );
# REFERENCE: report:database:top-users
__( q{Most Active Users, Top $users_to_show} );
# REFERENCE: report:database:top-users
__( q{Actions} );
# REFERENCE: report:database:top-users
__( q{% Total} );

==> lire_2.0.1.orig.tar.gz: lire-2.0.1/database/po/lire-database.pot.pl <==
# REFERENCE: database_default.xml
__( q{Database Report} );
# REFERENCE: schema:database
__( q{DLF Schema for Database service} );
# REFERENCE: schema:database
__( q{A record in the <type>database</type> DLF schema represents one event in the database. This may be a connection from a client, a SQL query, etc. } );
# REFERENCE: schema:database
__( q{Timestamp} );
# REFERENCE: schema:database
__( q{The time at which the event occured.} );
# REFERENCE: schema:database
__( q{User} );
# REFERENCE: schema:database
__( q{The name of the user who executed the command.} );
# REFERENCE: schema:database
__( q{Client Host} );
# REFERENCE: schema:database
__( q{The host from which the user executed the command.} );
# REFERENCE: schema:database
__( q{Query Action} );
# REFERENCE: schema:database
__( q{The command that was executed. Commands you are likely to encounter are <constant>connect</constant>, <constant>disconnect</constant>, <constant>shutdown</constant> and <constant>query</constant>. } );
# REFERENCE: schema:database
__( q{database} );
# REFERENCE: schema:database
__( q{The database name on which the command was executed.} );
# REFERENCE: schema:database
__( q{query} );
# REFERENCE: schema:database
__( q{When the <structfield>command</structfield> field is a <constant>query</constant>, this field contains the actual SQL query that was executed. } );
# REFERENCE: schema:database
__( q{Success?} );
# REFERENCE: schema:database
__( q{Did the command succeeded?} );
# REFERENCE: schema:database
__( q{Error} );
# REFERENCE: schema:database
__( q{When the <structfield>success</structfield> field is <constant>false</constant>, i.e. when the command failed, this field should contains the logged error message.} );
# REFERENCE: schema:database
__( q{Connection ID} );
# REFERENCE: schema:database
__( q{An "appropriate" "connection label" for the backend that can be used for session analysis in conjunction with the <structfield>timestamp</structfield>, <structfield>username</structfield> and <structfield>database</structfield> fields. This can be a connection identifier, a PID, a real session ID or whatever makes sense in the particular backend. } );
# REFERENCE: report:database:actions-by-period
__( q{Actions By Period Database Report} );
# REFERENCE: report:database:actions-by-period
__( q{This report shows the number of actions in configurable time periods. } );
# REFERENCE: report:database:actions-by-period
__( q{This parameter controls the time period over which the deliveries are aggregated. } );
# REFERENCE: report:database:actions-by-period
__( q{Actions By $period Period} );
# REFERENCE: report:database:actions-by-period
__( q{Period} );
# REFERENCE: report:database:actions-by-period
__( q{Actions} );
# REFERENCE: report:database:actions-by-period
__( q{% Total} );
# REFERENCE: report:database:top-databases
__( q{Most Accessed Databases Database Report} );
# REFERENCE: report:database:top-databases
__( q{This report lists the databases that were the most accessed.} );
# REFERENCE: report:database:top-databases
__( q{This parameter controls the number of databases to display in the report. } );
# REFERENCE: report:database:top-databases
__( q{Most Used Databases, Top $databases_to_show} );
# REFERENCE: report:database:top-databases
__( q{Actions} );
# REFERENCE: report:database:top-databases
__( q{Actions} );
# REFERENCE: report:database:top-querytypes
__( q{Queries By Type} );
# REFERENCE: report:database:top-querytypes
__( q{This report shows the number of queries by query type.} );
# REFERENCE: report:database:top-querytypes
__( q{Queries by Type} );
# REFERENCE: report:database:top-querytypes
__( q{Queries} );
# REFERENCE: report:database:top-querytypes
__( q{% Total} );
# REFERENCE: report:database:top-users
__( q{Most Active Users Database Report} );
# REFERENCE: report:database:top-users
__( q{This report lists the users that do the most actions.} );
# REFERENCE: report:database:top-users
__( q{This parameter controls the number of users to display in the report. } );
# REFERENCE: report:database:top-users
__( q{Most Active Users, Top $users_to_show} );
# REFERENCE: report:database:top-users
__( q{Actions} );
# REFERENCE: report:database:top-users
__( q{% Total} );
